==> nextcloud-24.0.12.zip: nextcloud/apps/text/l10n/zh_HK.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "新文字檔",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "寫入硬碟失敗",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "{user} has mentioned you in the text document {node}" : "{user} 在  {node} 的文字文件中提到了您",
    "This file cannot be displayed as download is disabled by the share" : "此檔案無法顯示，因為共享已禁用下載",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
    "Use current version" : "使用目前版本",
    "Use the saved version" : "使用儲存版本",
    "Failed to load file" : "加載檔案失敗",
    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
    "Reconnect" : "重新連接",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "File could not be loaded. Please check your internet connection." : "無法載入檔案。請檢查您的網路連線。",
    "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它當前被 {user} 鎖上。",
    "Close outline view" : "關閉大綱檢視",
    "Outline" : "大綱",
    "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
    "Edit guest name" : "編輯訪客名稱",
    "Guest" : "訪客",
    "Save guest name" : "儲存訪客名稱",
    "Insert an attachment" : "插入附件",
    "guest" : "訪客",
    "Show author colors" : "顯示作者顏色",
    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
    "Active people" : "活躍的人",
    "Last saved" : "最後保存於",
    "Offline" : "離線",
    "Offline, changes will be saved when online" : "離線，在線時更改將被保存",
    "Saving …" : "正在儲存……",
    "Saved" : "已儲存",
    "Last saved {lastSave}" : "上次儲存於 {lastSave}",
    "Unsaved changes" : "未儲存變更",
    "Formatting help" : "格式化說明",
    "Speed up your writing with simple shortcuts." : "使用簡單的快捷方式加快您的寫作速度。",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
    "Just type the Markdown syntax from below." : "只需輸入下方的 Markdown 語法即可。",
    "Style" : "樣式",
    "Syntax" : "語法",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "New paragraph" : "新段落",
    "Enter" : "輸入",
    "Hard line break" : "硬換行",
    "followed by" : "後接",
    "Backspace" : "Backspace",
    "Shift" : "轉移",
    "Bold" : "粗體",
    "Bold text" : "粗體文字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜體",
    "Italicized text" : "斜體文字",
    "Strikethrough" : "刪除線",
    "Mistaken text" : "錯誤的文字",
    "Underline" : "下面畫線",
    "Underlined text" : "下面畫線的文字",
    "Heading 1" : "標題 1",
    "Heading level 1" : "標題級別 1",
    "Heading 6" : "標題 6",
    "Heading level 6" : "標題級別 6",
    "Unordered list" : "無序清單",
    "An item" : "一個項目",
    "Ordered list" : "有序清單",
    "First item" : "第一個項目",
    "Checklist" : "清單",
    "To-Do item" : "待辦事項",
    "Blockquote" : "引文",
    "Quoted text" : "引用文字",
    "Code block" : "程式碼區塊",
    "Some code" : "一些代碼",
    "Upload from computer" : "從電腦上傳",
    "Insert from Files" : "從檔案插入",
    "Remove link" : "移除連結",
    "Link to file or folder" : "連結至檔案或資料夾",
    "Link to website" : "連結至網站",
    "Update link" : "更新鏈接",
    "Open the Smart Picker" : "打開智能選擇器",
    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
    "_%n word_::_%n words_" : ["%n 個單詞"],
    "_%n char_::_%n chars_" : ["%n 個字母"],
    "Formatting menu bar" : "格式化選項單欄",
    "Editor actions" : "編輯器操作",
    "Translate" : "翻譯",
    "Remaining actions" : "剩餘操作",
    "Source language" : "本源語言",
    "Target language" : "目標語言",
    "Replace" : "取代",
    "Insert" : "插入",
    "Detect language" : "檢測語言",
    "Translation failed" : "翻譯失敗",
    "No emoji found" : "找不到表情符號",
    "No command found" : "找不到命令",
    "No user found" : "找不到用戶",
    "No suggestion found" : "找不到建議",
    "Link to this section" : "連結到本節",
    "Delete this attachment" : "刪除此附件",
    "Delete this image" : "刪除此圖像",
    "Failed to load" : "加載失敗",
    "Unsupported image type" : "不支援的圖片類型",
    "Add row before" : "在前面添加行",
    "Add row after" : "在後面添加行",
    "Delete this row" : "刪除此行",
    "Left align column" : "左側對齊縱列",
    "Center align column" : "置中對齊縱列",
    "Right align column" : "右側對齊縱列",
    "Add column before" : "在前面添加縱列",
    "Add column after" : "在後面添加縱列",
    "Delete this column" : "删除此縱列",
    "Delete this table" : "删除此表",
    "Show rich workspaces" : "顯示較多功能的工作區",
    "Hide outline" : "隱藏大綱",
    "Show outline" : "顯示大綱",
    "Undo" : "復原",
    "Redo" : "重作",
    "Headings" : "標題",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "To-Do list" : "待辦事項清單",
    "Insert link" : "插入連結",
    "Callouts" : "標記",
    "Info" : "資訊",
    "Success" : "成功",
    "Warning" : "警告",
    "Danger" : "危險",
    "Table" : "表",
    "Insert emoji" : "插入 emoji",
    "Insert attachment" : "插入附件",
    "Command" : "指令",
    "Control" : "掌控",
    "Option" : "選項",
    "Add notes, lists or links …" : "加入筆記、清單或連結…",
    "Edit" : "編輯",
    "Add description" : "添加描述",
    "Front matter" : "前言",
    "Last saved {lastSaved}" : "上次儲存於 {lastSaved}",
    "Image file format not supported" : "不支持圖像格式",
    "Enter your name so other users can see who is editing" : "輸入您的名稱，這樣其他用戶才能查看是誰在編輯",
    "Todo item" : "待辦事項",
    "Insert an image" : "插入圖像",
    "Alt" : "Alt",
    "Update Link" : "更新連結",
    "Add Link" : "添加連結",
    "Link file" : "連結檔案",
    "Remove Link" : "移除連結",
    "Select file to link to" : "選擇要連結的檔案",
    "ToDo list" : "待辦清單",
    "Emoji picker" : "Emoji 選擇器",
    "Insert image" : "插入圖像",
    "Document save status" : "文件保存狀態",
    "Open link picker" : "打開連結選擇器"
},
"nplurals=1; plural=0;");

==> nextcloud-28.0.13rc1.zip: nextcloud/apps/text/l10n/zh_HK.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部分上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入磁碟",
    "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "New text file" : "新文字檔",
    "Create new text file" : "創建新文字檔案",
    "Editing session has expired. Please reload the page." : "編輯工作階段已過期。請重新載入頁面。",
    "{user} has mentioned you in the text document {node}" : "{user} 在  {node} 的文字文件中提到了您",
    "This file cannot be displayed as download is disabled by the share" : "此檔案無法顯示，因為共享已禁用下載",
    "File not found" : "找不到檔案",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
    "Nextcloud Assistant" : "Nextcloud 小幫手",
    "Translate" : "翻譯",
    "Show assistant results" : "顯示小幫手結果",
    "Assistant results" : "小幫手結果",
    "Insert result" : "插入結果",
    "Show result" : "顯示結果",
    "Delete task" : "刪除任務",
    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
    "Use current version" : "使用目前版本",
    "Use the saved version" : "使用儲存版本",
    "Reload" : "重新載入",
    "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
    "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
    "Reconnect" : "重新連接",
    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
    "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它當前被 {user} 鎖上。",
    "Close outline view" : "關閉大綱檢視",
    "Outline" : "大綱",
    "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
    "Edit guest name" : "編輯訪客名稱",
    "Guest" : "訪客",
    "Save guest name" : "儲存訪客名稱",
    "Uploading multiple attachments failed." : "上傳多個附件失敗。",
    "Uploading attachment failed: {error}" : "上傳附件失敗：{error}",
    "Uploading attachment failed." : "附件上傳失敗。",
    "Insert an attachment" : "插入附件",
    "Failed to insert from Files" : "從檔案插入失敗",
    "Preview options" : "預覽選項",
    "Text only" : "僅文字",
    "Show link preview" : "顯示連結預覽",
    "Remove link" : "移除連結",
    "guest" : "訪客",
    "Active people" : "活躍的人",
    "Save document" : "保存文件",
    "Last saved" : "最後保存於",
    "Offline" : "離線",
    "Offline, changes will be saved when online" : "離線，在線時更改將被保存",
    "Saving …" : "正在儲存……",
    "Saved" : "已儲存",
    "Last saved {lastSave}" : "上次儲存於 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "Unsaved changes" : "未儲存變更",
    "Connection failed." : "連線失敗。",
    "Formatting and shortcuts" : "排版和捷徑",
    "Speed up your writing with simple shortcuts." : "使用簡單的快捷方式加快您的寫作速度。",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需輸入 Markdown 語法或使用下方的鍵盤快捷鍵即可。",
    "Just type the Markdown syntax from below." : "只需輸入下方的 Markdown 語法即可。",
    "Style" : "樣式",
    "Syntax" : "語法",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "New paragraph" : "新段落",
    "Enter" : "輸入",
    "Hard line break" : "硬換行",
    "followed by" : "後接",
    "Backspace" : "Backspace",
    "Shift" : "轉移",
    "Bold" : "粗體",
    "Bold text" : "粗體文字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜體",
    "Italicized text" : "斜體文字",
    "Strikethrough" : "刪除線",
    "Mistaken text" : "錯誤的文字",
    "Underline" : "下面畫線",
    "Underlined text" : "下面畫線的文字",
    "Heading 1" : "標題 1",
    "Heading level 1" : "標題級別 1",
    "Heading 6" : "標題 6",
    "Heading level 6" : "標題級別 6",
    "Unordered list" : "無序清單",
    "An item" : "一個項目",
    "Ordered list" : "有序清單",
    "First item" : "第一個項目",
    "Checklist" : "清單",
    "To-Do item" : "待辦事項",
    "Blockquote" : "引文",
    "Quoted text" : "引用文字",
    "Code block" : "程式碼區塊",
    "Some code" : "一些代碼",
    "Link" : "連結",
    "Insert emoji" : "插入 emoji",
    "emoji" : "表情符號",
    "Mention someone" : "提及某人",
    "name" : "姓名",
    "Smart picker" : "聰明的選擇器",
    "something" : "某些東西",
    "Action" : "操作",
    "Undo" : "復原",
    "Redo" : "重作",
    "Toggle outline" : "切換大綱",
    "Alt" : "Alt",
    "Edit link" : "編輯連結",
    "Save changes" : "保存更改",
    "Cancel" : "取消",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
    "Copy link to clipboard" : "複製連結到剪貼板",
    "Upload from computer" : "從電腦上傳",
    "Insert from Files" : "從檔案插入",
    "Formatting help" : "格式化說明",
    "Link to file or folder" : "連結至檔案或資料夾",
    "Link to website" : "連結至網站",
    "Update link" : "更新鏈接",
    "Open the Smart Picker" : "打開智能選擇器",
    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
    "_%n word_::_%n words_" : ["%n 個單詞"],
    "_%n char_::_%n chars_" : ["%n 個字母"],
    "Editor actions" : "編輯器操作",
    "Formatting menu bar" : "格式化選項單欄",
    "Remaining actions" : "剩餘操作",
    "To translate individual parts of the text, select it before using the translate function." : "要翻譯部份文字，請在使用翻譯功能前選取該部份。",
    "Translate from" : "翻譯從",
    "Select language" : "選擇語言",
    "Text to translate from" : "要翻譯的文字",
    "to" : "至",
    "Translate to" : "翻譯至",
    "Translated text result" : "翻譯文字結果",
    "Replace" : "取代",
    "Insert" : "插入",
    "Detect language" : "檢測語言",
    "Translate from {language}" : "從 {language} 翻譯",
    "Translate to {language}" : "翻譯為 {language}",
    "Translation failed" : "翻譯失敗",
    "No emoji found" : "找不到表情符號",
    "No command found" : "找不到命令",
    "No user found" : "找不到用戶",
    "No suggestion found" : "找不到建議",
    "Edit" : "編輯",
    "Copy code block" : "複製程式碼區塊",
    "Copy code" : "複製代碼",
    "Code block options" : "程式碼區塊選項",
    "Code block language" : "程式碼區塊語言",
    "e.g. php, javascript, json…" : "例如 php、javascript、json ...",
    "Source code" : "原始碼",
    "Diagram" : "圖表",
    "Both" : "皆是",
    "Mermaid documentation" : "Mermaid 說明書",
    "Delete this attachment" : "刪除此附件",
    "Delete this image" : "刪除此圖像",
    "Failed to load" : "加載失敗",
    "Could not find image in attachments list." : "在附件清單中找不到影像。",
    "Add row before" : "在前面添加行",
    "Add row after" : "在後面添加行",
    "Delete this row" : "刪除此行",
    "Left align column" : "左側對齊縱列",
    "Center align column" : "置中對齊縱列",
    "Right align column" : "右側對齊縱列",
    "Add column before" : "在前面添加縱列",
    "Add column after" : "在後面添加縱列",
    "Delete this column" : "删除此縱列",
    "Delete this table" : "删除此表",
    "Add row below" : "在下方新增列",
    "Show folder description" : "顯示資料夾描述",
    "Hide outline" : "隱藏大綱",
    "Show outline" : "顯示大綱",
    "Headings" : "標題",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "Lists" : "清單",
    "To-Do list" : "待辦事項清單",
    "Increase indentation" : "增加縮排",
    "Decrease indentation" : "減少縮排",
    "Blocks" : "區塊",
    "Info callout" : "資訊標記",
    "Success callout" : "成功標記",
    "Warning callout" : "警告標記",
    "Danger callout" : "危險標記",
    "Table" : "表",
    "Details" : "細節",
    "Insert link" : "插入連結",
    "Insert attachment" : "插入附件",
    "Command" : "指令",
    "Control" : "掌控",
    "Option" : "選項",
    "Formatting" : "正在格式化",
    "Start writing, or try '/' to add, '@' to mention…" : "開始撰寫，或試試看「/」新增、「@」提及……",
    "Add folder description" : "新增資料夾描述",
    "\"{name}\" already exist!" : "「{name}」已存在！",
    "Created \"{name}\"" : "已建立「{name}」",
    "Copied to the clipboard" : "已複製到剪貼板",
    "Could not copy to the clipboard" : "無法複製到剪貼簿",
    "Front matter" : "前言",
    "Link to this section" : "連結到本節",
    "Show author colors" : "顯示作者顏色",
    "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
    "Callouts" : "標記",
    "Info" : "資訊",
    "Success" : "成功",
    "Warning" : "警告",
    "Danger" : "危險",
    "Add notes, lists or links …" : "加入筆記、清單或連結…",
    "Add description" : "添加描述"
},
"nplurals=1; plural=0;");
